@@ -8,7 +8,7 @@ use MooX::StrictConstructor;
 use MooX::Types::MooseLike::Base qw(Bool CodeRef);
 use namespace::autoclean;
 
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 
 has is_strict => (
     is  => 'rw',
@@ -50,7 +50,7 @@ sub expand_named {
             : @args
         };
 
-    my $regex = join q{|}, map { quotemeta $_ } keys %{$arg_ref};
+    my $regex = join q{|}, map { quotemeta } keys %{$arg_ref};
     ## no critic (EscapedMetacharacters)
     $text =~ s{
         (
@@ -78,13 +78,13 @@ __END__
 
 Locale::Utils::PlaceholderNamed - Utils to expand named placeholders
 
-$Id: PlaceholderNamed.pm 569 2015-02-02 07:45:21Z steffenw $
+$Id: PlaceholderNamed.pm 587 2015-04-16 05:58:10Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/Locale-Utils-PlaceholderNamed/trunk/lib/Locale/Utils/PlaceholderNamed.pm $
 
 =head1 VERSION
 
-1.001
+1.002
 
 =head1 SYNOPSIS
 
@@ -114,6 +114,10 @@ Utils to expand named placeholders.
 
 =head1 SUBROUTINES/METHODS
 
+=head2 method new
+
+see SYNOPSIS
+
 =head2 method is_strict
 
 If is_strict is false: undef will be converted to q{}.
@@ -213,7 +217,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2011 - 2015,
+Copyright (c) 2011 - 2017,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
